@@ -137,13 +137,13 @@ public:
             iconPath = KIconLoader::global()->iconPath(QStringLiteral("folder"), -32, false);
         }
 
-        QString tipIcon = QStringLiteral(
-                              "      <table border=\"0\"><tr><td width=\"32\" height=\"32\" align=\"center\" valign=\"middle\">\n"
-                              "      <img src=\"%1\" width=\"%2\" height=\"32\">\n"
-                              "      </td></tr></table>\n"
-                              "    </td>\n")
-                              .arg(iconPath)
-                              .arg(icon_size_found);
+        const QString tipIcon = QStringLiteral(
+                                    "      <table border=\"0\"><tr><td width=\"32\" height=\"32\" align=\"center\" valign=\"middle\">\n"
+                                    "      <img src=\"%1\" width=\"%2\" height=\"32\">\n"
+                                    "      </td></tr></table>\n"
+                                    "    </td>\n")
+                                    .arg(iconPath)
+                                    .arg(icon_size_found);
 
         if (QApplication::layoutDirection() == Qt::LeftToRight) {
             tip += tipInfo + QStringLiteral("</td><td align=\"%3\" valign=\"top\">").arg(textDirection) + tipIcon;
@@ -185,11 +185,13 @@ void StatisticsProxyModel::setSourceModel(QAbstractItemModel *model)
     }
     KExtraColumnsProxyModel::setSourceModel(model);
     if (model) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 8, 0)
         // Disconnect the default handling of dataChanged in QIdentityProxyModel, so we can extend it to the whole row
         disconnect(model,
                    SIGNAL(dataChanged(QModelIndex, QModelIndex, QList<int>)), // clazy:exclude=old-style-connect
                    this,
                    SLOT(_q_sourceDataChanged(QModelIndex, QModelIndex, QList<int>)));
+#endif
         connect(model, &QAbstractItemModel::dataChanged, this, [this](const auto &tl, const auto &br, const auto &roles) {
             d->_k_sourceDataChanged(tl, br, roles);
         });
@@ -201,6 +203,10 @@ StatisticsProxyModel::StatisticsProxyModel(QObject *parent)
     , d(new StatisticsProxyModelPrivate(this))
 {
     setExtraColumnsEnabled(true);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 8, 0)
+    // Disable the default handling of dataChanged in QIdentityProxyModel, so we can extend it to the whole row
+    setHandleSourceDataChanges(false);
+#endif
 }
 
 StatisticsProxyModel::~StatisticsProxyModel() = default;
